@@ -1,4 +1,5 @@
 use std::io;
+use std::sync::Arc;
 
 use tui::{
     backend::CrosstermBackend,
@@ -21,7 +22,7 @@ impl Drawable for EventsView {
         &mut self,
         f: &mut Frame<CrosstermBackend<io::Stdout>>,
         area: Rect,
-        app: &AppState,
+        app: Arc<AppState>,
     ) {
         if let Some(event) = &app.events.read().await.current_event {
             let mut style = Style::default().add_modifier(Modifier::BOLD);
